@@ -1,8 +1,6 @@
 package Catmandu::RIS;
 
-use strict;
-use 5.008_005;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 1;
 __END__
@@ -31,10 +29,6 @@ Nicolas Steenlant
 
 Vitali Peil
 
-=head1 COPYRIGHT
-
-Copyright 2015- Vitali Peil
-
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify
